<?php
$TRANSLATIONS = array(
"Pictures" => "Slike",
"Picture view" => "Slikovni pogled",
"Error loading slideshow template" => "Napaka nalaganja predloge za slikovno predstavitev",
"Share" => "Souporaba",
"No pictures found! If you upload pictures in the files app, they will be displayed here." => "Ni najdenih slik! Če shranite slike kjerkoli med datoteke, bodo tu prikazane kot galerije.",
"shared by %s" => "v souporabi preko %s",
"File list" => "Seznam datotek"
);
$PLURAL_FORMS = "nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);";
